@@ -56,6 +56,21 @@ sub new
 	return $self;
 }
 
+=head2
+
+return a list of all id of the SpecialFileContainers.
+
+=cut
+
+sub get_all_media_id {
+	my $self = shift;
+	my %shortnames=();
+	foreach my $obj (@{$self->get_all}){
+		$shortnames{$obj->id}=1;
+	}
+	return keys(%shortnames);
+}
+
 
 =head1 AUTHOR
 
@@ -64,13 +79,52 @@ DUPUIS Arnaud, C<< <a.dupuis@infinityperl.org> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to
-C<bug-slackget10-SpecialFileContainerList@rt.cpan.org>, or through the web interface at
+C<bug-slackget10@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=slackget10>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc slackget10
+
+
+You can also look for information at:
+
+=over 4
+
+=item * Infinity Perl website
+
+L<http://www.infinityperl.org/category/slack-get>
+
+=item * slack-get specific website
+
+L<http://slackget.infinityperl.org>
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=slackget10>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/slackget10>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/slackget10>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/slackget10>
+
+=back
+
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to Bertrand Dupuis (yes my brother) for his contribution to the documentation.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2005 DUPUIS Arnaud, All Rights Reserved.
